﻿namespace U2UConsult.Metro.SettingsSample
{
    using Caliburn.Micro;
    using Windows.Foundation;
    using Windows.UI.ApplicationSettings;
    using Windows.UI.Xaml;
    using Windows.UI.Xaml.Controls;
    using Windows.UI.Xaml.Controls.Primitives;

    /// <summary>
    /// Application Settings Panel Logic
    /// </summary>
    sealed partial class App : Application
    {
        Popup _settingsPopup;
        double _settingsWidth = 346; // Use 646 for wide settings screen

        // TODO: get initial settings from local storage, skydrive, cloud, or whatever.
        private AppSettings appSettings = new AppSettings { NumberOfBottles = 2 };

        public AppSettings AppSettings
        {
            get
            {
                return this.appSettings;
            }
        }

        /// <summary>
        /// Register application settings commands.
        /// </summary>
        private void RegisterAppSettings()
        {
            SettingsPane.GetForCurrentView().CommandsRequested += App_CommandsRequested;
        }

        /// <summary>
        /// SettingsPane was requested.
        /// </summary>
        private void App_CommandsRequested(SettingsPane sender, SettingsPaneCommandsRequestedEventArgs args)
        {
            SettingsCommand cmd = new SettingsCommand("SettingsId", "Preferences", (x) =>
            {
                Rect windowBounds = Window.Current.Bounds;

                // Create popup
                _settingsPopup = new Popup()
                    {
                        IsLightDismissEnabled = true,
                        Width = _settingsWidth,
                        Height = windowBounds.Height
                    };
                _settingsPopup.Closed += OnPopupClosed;
                _settingsPopup.SetValue(Canvas.LeftProperty, windowBounds.Width - _settingsWidth);
                _settingsPopup.SetValue(Canvas.TopProperty, 0);

                // Create settings pane
                AppSettingsPane appSettingsPane = new AppSettingsPane()
                    {
                        Width = _settingsWidth,
                        Height = windowBounds.Height,
                        DataContext = new AppSettings
                            {
                                NumberOfBottles = this.appSettings.NumberOfBottles,
                                UseGlass = this.appSettings.UseGlass
                            } // A copy of the settings, so app working screen bindings are not updated
                    };

                // Hook settings pane in popup
                _settingsPopup.Child = appSettingsPane;

                // Display popup
                _settingsPopup.IsOpen = true;
            });

            // Make commands available in settings pane
            args.Request.ApplicationCommands.Add(cmd);
        }

        /// <summary>
        /// Settings pane is closed. Broadcast new settings.
        /// </summary>
        private void OnPopupClosed(object sender, object e)
        {
            _settingsPopup.Closed -= OnPopupClosed;

            AppSettings newSettings = (_settingsPopup.Child as FrameworkElement).DataContext as AppSettings;
            if (newSettings != null)
            {
                // Update app settings
                this.appSettings = newSettings;

                // Broadcast the new settings
                EventAggregator.Instance.Publish(this.appSettings);
            }
        }
    }
}
