﻿namespace U2UConsult.Metro.SettingsSample
{
    using Caliburn.Micro;
    using Windows.UI.ApplicationSettings;
    using Windows.UI.Xaml;
    using Windows.UI.Xaml.Controls;
    using Windows.UI.Xaml.Navigation;

    /// <summary>
    /// A page with some bindings to app settings, and a button to open the settings charm.
    /// </summary>
    public sealed partial class BlankPage : Page, IHandle<AppSettings>
    {
        public BlankPage()
        {
            this.InitializeComponent();
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            // Subscribe
            EventAggregator.Instance.Subscribe(this);

            // Get current settings
            this.SettingsGrid.DataContext = (App.Current as App).AppSettings;
        }

        /// <summary>
        /// Open the settings pane programmatically.
        /// </summary>
        private void SettingsButton_Click(object sender, RoutedEventArgs e)
        {
            SettingsPane.Show();
        }

        /// <summary>
        /// Handle app settings change.
        /// </summary>
        /// <param name="settings">new settings</param>
        public void Handle(AppSettings settings)
        {
            this.SettingsGrid.DataContext = settings;
        }
    }
}